Notebooks
========================================================================================

.. toctree::
    :maxdepth: 1

    Tract-Patch Search <pre_executed/tract_patch_search>
    Plotting light curves <notebooks/plot_light_curves>
